pub fn spawn_two_on_death(ctx: &EventCtx<'_>) -> Result<Vec<OverlordEvent>>Expand description
Port of the test “spawn two enemies on death” effect (39f135d2-...),
Each spawn draws a random uuid from the authoritative RNG (in order, like the
pub fn spawn_two_on_death(ctx: &EventCtx<'_>) -> Result<Vec<OverlordEvent>>Port of the test “spawn two enemies on death” effect (39f135d2-...),
Each spawn draws a random uuid from the authoritative RNG (in order, like the